@@ -1,11 +1,12 @@
 package My::Module::Meta;
 
-use 5.006;
+use 5.006002;
 
 use strict;
 use warnings;
 
 use Carp;
+use Config;
 use POSIX qw{ uname };
 
 sub new {
@@ -28,11 +29,15 @@ sub build_requires {
 
 sub ccflags {
     my @ccflags;
+
     my ( $darwin_version ) = split qr{ [.] }smx, ( uname() )[2];
     $darwin_version >= 8
 	and push @ccflags, '-DTIGER';
-    -f '/usr/include/MacTypes.h'
-	and push @ccflags, '-DUSE_MACTYPES';
+
+    system "$Config{cc} -fsyntax-only inc/trytypes.c 2>/dev/null";
+    $?
+	or push @ccflags, '-DUSE_MACTYPES';
+
     if ( my $debug = $ENV{DEVELOPER_DEBUG} ) {
 	push @ccflags, '-DDEBUG_PBL';
 	$debug =~ m/ \b backtrace \b /smxi
@@ -85,7 +90,7 @@ sub requires {
 }
 
 sub requires_perl {
-    return 5.006;
+    return 5.006002;
 }
 
 sub want_pbtool {
@@ -257,7 +262,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010-2016 by Thomas R. Wyant, III
+Copyright (C) 2010-2017 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
