@@ -8,9 +8,9 @@ use warnings;
 use Carp;
 use Test::More 0.88;
 
-use base qw{ Exporter };
+use Exporter qw{ import };
 
-our $VERSION = '0.008';
+our $VERSION = '0.009';
 
 our @EXPORT =		## no critic (ProhibitAutomaticExportation)
 qw{
@@ -220,7 +220,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2013-2016 by Thomas R. Wyant, III
+Copyright (C) 2013-2017 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
